abacusai.feature_drift_summary — AbacusAI documentation

# abacusai.feature_drift_summary

## Classes

`FeatureDriftSummary` | Summary of important model monitoring statistics for features available in a model monitoring instance

## Module Contents

class abacusai.feature_drift_summary.FeatureDriftSummary(client, featureIndex=None, name=None, distance=None, jsDistance=None, wsDistance=None, ksStatistic=None, predictionDrift=None, targetColumn=None, dataIntegrityTimeseries=None, nestedSummary=None, psi=None, csi=None, chiSquare=None, nullViolations={}, rangeViolations={}, catViolations={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important model monitoring statistics for features available in a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureIndex (list[dict]) – A list of dicts of eligible feature names and corresponding overall feature drift measures.

    - name (str) – Name of feature.

    - distance (float) – Symmetric sum of KL divergences between the training distribution and the range of values in the specified window.

    - jsDistance (float) – JS divergence between the training distribution and the range of values in the specified window.

    - wsDistance (float) – Wasserstein distance between the training distribution and the range of values in the specified window.

    - ksStatistic (float) – Kolmogorov-Smirnov statistic computed between the training distribution and the range of values in the specified window.

    - predictionDrift (float) – Drift for the target column.

    - targetColumn (str) – Target column name.

    - dataIntegrityTimeseries (dict) – Frequency vs Data Integrity Violation Charts.

    - nestedSummary (list[dict]) – Summary of model monitoring statistics for nested features.

    - psi (float) – Population stability index computed between the training distribution and the range of values in the specified window.

    - csi (float) – Characteristic Stability Index computed between the training distribution and the range of values in the specified window.

    - chiSquare (float) – Chi-square statistic computed between the training distribution and the range of values in the specified window.

    - nullViolations (NullViolation) – A list of dicts of feature names and a description of corresponding null violations.

    - rangeViolations (RangeViolation) – A list of dicts of numerical feature names and corresponding prediction range discrepancies.

    - catViolations (CategoricalRangeViolation) – A list of dicts of categorical feature names and corresponding prediction range discrepancies.

  feature_index = None
  name = None
  distance = None
  js_distance = None
  ws_distance = None
  ks_statistic = None
  prediction_drift = None
  target_column = None
  data_integrity_timeseries = None
  nested_summary = None
  psi = None
  csi = None
  chi_square = None
  null_violations
  range_violations
  cat_violations
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict